==> xmgfv1.9.1.tar.gz: xmgf/inc/Pixmaps.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
void             SavePGMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveXBMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePBMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePPMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveGIFCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveRASCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveFRAMECB (Widget w, caddr_t client_data, caddr_t call_data);
void             OutputPGM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputXBM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPBM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPPM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputRAS (char *fname, int x, int y, int width, int height, Window TmpWind, int Col);
void             OutputGIF (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputFRAME (char *fname, int Col);
void             OutputPARM (char *fname);
void             InputPARM (char *fname);
void             OutputFIG (char *fname, int Col);
void             OutputPS (char *fname, int Col, int Orientation);
void             OutputRAY (char *fname);
int             Image_Size (XImage * image);
Widget          CreateFileSelect (Widget parent, String name, String message, String mask, String Defaultfname, ArgList arglist, int argcount, char *DirName);
int             FICB (Widget w, caddr_t client_data, caddr_t call_data);
int             NOFICB (Widget w, caddr_t client_data, caddr_t call_data);
int             XmFileSelect (char *Title, int FileType, char *mask, char *Defaultfname, char *PWD);
void             write_sun_long (long l, FILE * fp);
void            compress (int init_bits, FILE * outfile, unsigned char *data, int len);
void            putword (int w,FILE *fp);
void            flush_char (void);
void            char_out (int c);
void            char_init (void);
void            cl_block (void);
void            cl_hash (register long int hsize);
void            output (int code);
void             WriteGIF (FILE *fp, unsigned char *pic, int w,int  h, unsigned char *rmap,unsigned char *gmap,unsigned char *bmap, int numcols,int  colorstyle);
#else
void             SavePGMCB ();
void             SaveXBMCB ();
void             SavePBMCB ();
void             SavePPMCB ();
void             SaveGIFCB ();
void             SaveRASCB ();
void             OutputPGM ();
void             OutputXBM ();
void             OutputPBM ();
void             OutputPPM ();
void             OutputRAS ();
void             OutputGIF ();
void             OutputPARM ();
void             InputPARM ();
void             OutputFRAME ();
void             OutputFIG ();
void             OutputPS ();
void             OutputRAY ();
int             Image_Size ();
Widget          CreateFileSelect ();
int             FICB ();
int             NOFICB ();
int             XmFileSelect ();
void             write_sun_long ();
void            compress ();
void            putword ();
void            flush_char ();
void            char_out ();
void            char_init ();
void            cl_block ();
void            cl_hash ();
void            output ();
void             WriteGIF ();
#endif

#ifndef _NO_PROTO
int DetermineFillType(int fill,int num,int PtType,int FillStyle,int BaseType);
#else
int DetermineFillType();
#endif

==> xmgfv2.4.tar.gz: xmgf/inc/Pixmaps.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

typedef unsigned char byte;

#ifndef _NO_PROTO
void             SavePGMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveXBMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePBMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePPMCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveGIFCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveRASCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SaveFRAMECB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePCXCB (Widget w, caddr_t client_data, caddr_t call_data);
void             SavePICTCB (Widget w, caddr_t client_data, caddr_t call_data);
void             OutputPGM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputXBM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPBM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPPM (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputRAS (char *fname, int x, int y, int width, int height, Window TmpWind, int Col);
void             OutputGIF (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPCX (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputPICT (char *fname, int x, int y, int width, int height, Window TmpWind);
void             OutputFRAME (char *fname, int Col);
void             OutputPARM (char *fname);
void             InputPARM (char *fname);
void             OutputFIG (char *fname, int Col);
void             OutputPS (char *fname, int Col, int Orientation);
void             OutputRAY (char *fname);
int             Image_Size (XImage * image);
Widget          CreateFileSelect (Widget parent, String name, String message, String mask, String Defaultfname, ArgList arglist, int argcount, char *DirName);
int             FICB (Widget w, caddr_t client_data, caddr_t call_data);
int             NOFICB (Widget w, caddr_t client_data, caddr_t call_data);
int             XmFileSelect (char *Title, int FileType, char *mask, char *Defaultfname, char *PWD);
void             write_sun_long (long l, FILE * fp);
void            compress (int init_bits, FILE * outfile, unsigned char *data, int len);
void            putword (int w,FILE *fp);
void            flush_char (void);
void            char_out (int c);
void            char_init (void);
void            cl_block (void);
void            cl_hash (register long int hsize);
void            output (int code);
void             WriteGIF (FILE *fp, byte *pic, int w,int  h, byte *rmap,byte *gmap,byte *bmap, int numcols,int  colorstyle);
#else
void             SavePGMCB ();
void             SaveXBMCB ();
void             SavePBMCB ();
void             SavePPMCB ();
void             SaveGIFCB ();
void             SaveRASCB ();
void             SavePCXCB ();
void             SavePICTCB ();
void             OutputPGM ();
void             OutputXBM ();
void             OutputPBM ();
void             OutputPPM ();
void             OutputRAS ();
void             OutputGIF ();
void             OutputPARM ();
void             InputPARM ();
void             OutputFRAME ();
void             OutputFIG ();
void             OutputPS ();
void             OutputPICT ();
void             OutputRAY ();
int             Image_Size ();
Widget          CreateFileSelect ();
int             FICB ();
int             NOFICB ();
int             XmFileSelect ();
void             write_sun_long ();
void            compress ();
void            putword ();
void            flush_char ();
void            char_out ();
void            char_init ();
void            cl_block ();
void            cl_hash ();
void            output ();
void             WriteGIF ();
#endif

#ifndef _NO_PROTO
int DetermineFillType(int fill,int num,int PtType,int FillStyle,int BaseType);
#else
int DetermineFillType();
#endif
